# Changelog

## [0.2] - 2024-03-05
### Added
- Use logging module instead of print function
- Add ALL request
### Changed
- Change serial-number from 14 to 12 characters, without additional encoding
- Change execution order of pattern file aliases
### Fixed
### Docs
- Reduce README introduction text
- Add image of cascaded relay boards
- Add example how to integrate package into own python module
- Add "all" feature
- Add pipenv
- Add pattern execution order
- Add relay board supply voltage and current
- Add pin-mapping image for TC2050-430 adapter
- Add images of RB-1-10-01
- Add features section

## [0.1] - 2024-02-17
### Added
- Initial release
### Changed
### Fixed
### Docs
